<?php

namespace Drupal\cforge;

use Drupal\Core\StringTranslation\TranslationManager as DrupalTranslationManager;
use Drupal\Core\Language\LanguageDefault;

/**
 * Defines a chained translation implementation combining multiple translators.
 */
class TranslationManager extends DrupalTranslationManager {

  /**
   * All the strings which will be replaced
   * @var array
   */
  private $from;

  /**
   * All the replacement strings.
   * @var array
   */
  private $to;


  /**
   * Constructs a TranslationManager object.
   *
   * @param \Drupal\Core\Language\LanguageDefault $default_language
   *   The default language.
   */
  public function __construct(LanguageDefault $default_language) {
    parent::__construct($default_language);
    $terminology = (array) \Drupal::config('cforge.settings')->get('terminology');
    $this->from = array_keys($terminology);
    array_walk($this->from, function (&$s) {$s = '/[^@%]'.$s.'/';});
    $this->to = array_values($terminology);
  }

  /**
   * {@inheritdoc}
   */
  public function getStringTranslation($langcode, $string, $context) {
    $translation = parent::getStringTranslation($langcode, $string, $context);
    if ($translation) {
      // Return the translated, altered string
      // Note that replacements have not been done yet
      return preg_replace($this->from, $this->to, $string);
    }
    return FALSE;
  }
}
